summaryrefslogtreecommitdiff
path: root/src/mongo/s/collection_metadata.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/s/collection_metadata.h')
-rw-r--r--src/mongo/s/collection_metadata.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/mongo/s/collection_metadata.h b/src/mongo/s/collection_metadata.h
index 9916e41c185..a4a0094a577 100644
--- a/src/mongo/s/collection_metadata.h
+++ b/src/mongo/s/collection_metadata.h
@@ -75,7 +75,7 @@ namespace mongo {
* If a new metadata can't be created, returns NULL and fills in 'errMsg', if it was
* provided.
*/
- CollectionMetadata* cloneMinusPending( const ChunkType& pending, string* errMsg ) const;
+ CollectionMetadata* cloneMinusPending( const ChunkType& pending, std::string* errMsg ) const;
/**
* Returns a new metadata's instance based on 'this's state by adding a 'pending' chunk.
@@ -86,7 +86,7 @@ namespace mongo {
* If a new metadata can't be created, returns NULL and fills in 'errMsg', if it was
* provided.
*/
- CollectionMetadata* clonePlusPending( const ChunkType& pending, string* errMsg ) const;
+ CollectionMetadata* clonePlusPending( const ChunkType& pending, std::string* errMsg ) const;
/**
* Returns a new metadata's instance based on 'this's state by removing 'chunk'.
@@ -98,7 +98,7 @@ namespace mongo {
*/
CollectionMetadata* cloneMigrate( const ChunkType& chunk,
const ChunkVersion& newShardVersion,
- string* errMsg ) const;
+ std::string* errMsg ) const;
/**
* Returns a new metadata's instance by splitting an existing 'chunk' at the points
@@ -112,9 +112,9 @@ namespace mongo {
* Note: 'splitKeys' must be sorted in ascending order.
*/
CollectionMetadata* cloneSplit( const ChunkType& chunk,
- const vector<BSONObj>& splitKeys,
+ const std::vector<BSONObj>& splitKeys,
const ChunkVersion& newShardVersion,
- string* errMsg ) const;
+ std::string* errMsg ) const;
/**
* Returns a new metadata instance by merging a key range which starts and ends at existing
@@ -127,7 +127,7 @@ namespace mongo {
CollectionMetadata* cloneMerge( const BSONObj& minKey,
const BSONObj& maxKey,
const ChunkVersion& newShardVersion,
- string* errMsg ) const;
+ std::string* errMsg ) const;
//
// verification logic
@@ -234,9 +234,9 @@ namespace mongo {
void toBSONPending( BSONArrayBuilder& bb ) const;
/**
* String output of the metadata information.
*/
- string toString() const;
+ std::string toString() const;
/**
* Use the MetadataLoader to fill the empty metadata from the config server, or use
@@ -258,7 +258,7 @@ namespace mongo {
*/
CollectionMetadata* clonePlusChunk( const ChunkType& chunk,
const ChunkVersion& newShardVersion,
- string* errMsg ) const;
+ std::string* errMsg ) const;
private:
// Effectively, the MetadataLoader is this class's builder. So we open an exception
@@ -234,9 +234,9 @@ namespace mongo {
void toBSONPending( BSONArrayBuilder& bb ) const;
/**
- * String output of the metadata information.
+ * std::string output of the metadata information.
*/